@@ -6,8 +6,8 @@ Run benchmarks with::
     nib.bench()
 
 If you have doctests enabled by default in nose (with a noserc file or
-environment variable), and you have a numpy version <= 1.6.1, this will also run
-the doctests, let's hope they pass.
+environment variable), and you have a numpy version <= 1.6.1, this will also
+run the doctests, let's hope they pass.
 
 Run this benchmark with:
 
@@ -19,13 +19,12 @@ import sys
 
 import numpy as np
 
-from ..externals.six import BytesIO
-from ..volumeutils import array_to_file
 
 from .butils import print_git_title
 
 from numpy.testing import measure
 
+
 def bench_array_to_file():
     rng = np.random.RandomState(20111001)
     repeat = 10
