@@ -1,11 +1,15 @@
+""" Read / write FreeSurfer geometry, morphometry, label, annotation formats
+"""
 from __future__ import division, print_function, absolute_import
 
+import warnings
 import numpy as np
 import getpass
 import time
 
-
-from .. externals.six.moves import xrange
+from ..externals import OrderedDict
+from ..externals.six.moves import xrange
+from ..openers import Opener
 
 
 def _fread3(fobj):
@@ -43,28 +47,83 @@ def _fread3_many(fobj, n):
     return (b1 << 16) + (b2 << 8) + b3
 
 
-def read_geometry(filepath):
+def _read_volume_info(fobj):
+    """Helper for reading the footer from a surface file."""
+    volume_info = OrderedDict()
+    head = np.fromfile(fobj, '>i4', 1)
+    if not np.array_equal(head, [20]):  # Read two bytes more
+        head = np.concatenate([head, np.fromfile(fobj, '>i4', 2)])
+        if not np.array_equal(head, [2, 0, 20]):
+            warnings.warn("Unknown extension code.")
+            return volume_info
+
+    volume_info['head'] = head
+    for key in ['valid', 'filename', 'volume', 'voxelsize', 'xras', 'yras',
+                'zras', 'cras']:
+        pair = fobj.readline().decode('utf-8').split('=')
+        if pair[0].strip() != key or len(pair) != 2:
+            raise IOError('Error parsing volume info.')
+        if key in ('valid', 'filename'):
+            volume_info[key] = pair[1].strip()
+        elif key == 'volume':
+            volume_info[key] = np.array(pair[1].split()).astype(int)
+        else:
+            volume_info[key] = np.array(pair[1].split()).astype(float)
+    # Ignore the rest
+    return volume_info
+
+
+def read_geometry(filepath, read_metadata=False, read_stamp=False):
     """Read a triangular format Freesurfer surface mesh.
 
     Parameters
     ----------
     filepath : str
-        Path to surface file
+        Path to surface file.
+    read_metadata : bool, optional
+        If True, read and return metadata as key-value pairs.
+
+        Valid keys:
+
+        * 'head' : array of int
+        * 'valid' : str
+        * 'filename' : str
+        * 'volume' : array of int, shape (3,)
+        * 'voxelsize' : array of float, shape (3,)
+        * 'xras' : array of float, shape (3,)
+        * 'yras' : array of float, shape (3,)
+        * 'zras' : array of float, shape (3,)
+        * 'cras' : array of float, shape (3,)
+
+    read_stamp : bool, optional
+        Return the comment from the file
 
     Returns
     -------
     coords : numpy array
-        nvtx x 3 array of vertex (x, y, z) coordinates
+        nvtx x 3 array of vertex (x, y, z) coordinates.
     faces : numpy array
-        nfaces x 3 array of defining mesh triangles
+        nfaces x 3 array of defining mesh triangles.
+    volume_info : OrderedDict
+        Returned only if `read_metadata` is True.  Key-value pairs found in the
+        geometry file.
+    create_stamp : str
+        Returned only if `read_stamp` is True.  The comment added by the
+        program that saved the file.
     """
+    volume_info = OrderedDict()
+
+    TRIANGLE_MAGIC = 16777214
+    QUAD_MAGIC = 16777215
+    NEW_QUAD_MAGIC = 16777213
     with open(filepath, "rb") as fobj:
         magic = _fread3(fobj)
-        if magic == 16777215:  # Quad file
+        if magic in (QUAD_MAGIC, NEW_QUAD_MAGIC):  # Quad file
             nvert = _fread3(fobj)
             nquad = _fread3(fobj)
-            coords = np.fromfile(fobj, ">i2", nvert * 3).astype(np.float)
-            coords = coords.reshape(-1, 3) / 100.0
+            (fmt, div) = (">i2", 100.) if magic == QUAD_MAGIC else (">f4", 1.)
+            coords = np.fromfile(fobj, fmt, nvert * 3).astype(np.float) / div
+            coords = coords.reshape(-1, 3)
             quads = _fread3_many(fobj, nquad * 4)
             quads = quads.reshape(nquad, 4)
             #
@@ -84,33 +143,61 @@ def read_geometry(filepath):
                     faces[nface] = quad[0], quad[2], quad[3]
                     nface += 1
 
-        elif magic == 16777214:  # Triangle file
-            fobj.readline()  # create_stamp
+        elif magic == TRIANGLE_MAGIC:  # Triangle file
+            create_stamp = fobj.readline().rstrip(b'\n').decode('utf-8')
             fobj.readline()
             vnum = np.fromfile(fobj, ">i4", 1)[0]
             fnum = np.fromfile(fobj, ">i4", 1)[0]
             coords = np.fromfile(fobj, ">f4", vnum * 3).reshape(vnum, 3)
             faces = np.fromfile(fobj, ">i4", fnum * 3).reshape(fnum, 3)
+
+            if read_metadata:
+                volume_info = _read_volume_info(fobj)
         else:
             raise ValueError("File does not appear to be a Freesurfer surface")
 
     coords = coords.astype(np.float)  # XXX: due to mayavi bug on mac 32bits
-    return coords, faces
+
+    ret = (coords, faces)
+    if read_metadata:
+        if len(volume_info) == 0:
+            warnings.warn('No volume information contained in the file')
+        ret += (volume_info,)
+    if read_stamp:
+        ret += (create_stamp,)
+
+    return ret
 
 
-def write_geometry(filepath, coords, faces, create_stamp=None):
+def write_geometry(filepath, coords, faces, create_stamp=None,
+                   volume_info=None):
     """Write a triangular format Freesurfer surface mesh.
 
     Parameters
     ----------
     filepath : str
-        Path to surface file
+        Path to surface file.
     coords : numpy array
-        nvtx x 3 array of vertex (x, y, z) coordinates
+        nvtx x 3 array of vertex (x, y, z) coordinates.
     faces : numpy array
-        nfaces x 3 array of defining mesh triangles
-    create_stamp : str
+        nfaces x 3 array of defining mesh triangles.
+    create_stamp : str, optional
         User/time stamp (default: "created by <user> on <ctime>")
+    volume_info : dict-like or None, optional
+        Key-value pairs to encode at the end of the file.
+
+        Valid keys:
+
+        * 'head' : array of int
+        * 'valid' : str
+        * 'filename' : str
+        * 'volume' : array of int, shape (3,)
+        * 'voxelsize' : array of float, shape (3,)
+        * 'xras' : array of float, shape (3,)
+        * 'yras' : array of float, shape (3,)
+        * 'zras' : array of float, shape (3,)
+        * 'cras' : array of float, shape (3,)
+
     """
     magic_bytes = np.array([255, 255, 254], dtype=np.uint8)
 
@@ -128,6 +215,10 @@ def write_geometry(filepath, coords, faces, create_stamp=None):
         coords.astype('>f4').reshape(-1).tofile(fobj)
         faces.astype('>i4').reshape(-1).tofile(fobj)
 
+        # Add volume info, if given
+        if volume_info is not None and len(volume_info) > 0:
+            fobj.write(_serialize_volume_info(volume_info))
+
 
 def read_morph_data(filepath):
     """Read a Freesurfer morphometry data file.
@@ -146,7 +237,6 @@ def read_morph_data(filepath):
     -------
     curv : numpy array
         Vector representation of surface morpometry values
-
     """
     with open(filepath, "rb") as fobj:
         magic = _fread3(fobj)
@@ -160,6 +250,51 @@ def read_morph_data(filepath):
     return curv
 
 
+def write_morph_data(file_like, values, fnum=0):
+    """Write Freesurfer morphometry data `values` to file-like `file_like`
+
+    Equivalent to FreeSurfer's `write_curv.m`_
+
+    See also:
+    http://www.grahamwideman.com/gw/brain/fs/surfacefileformats.htm#CurvNew
+
+    .. _write_curv.m: \
+    https://github.com/neurodebian/freesurfer/blob/debian-sloppy/matlab/write_curv.m
+
+    Parameters
+    ----------
+    file_like : file-like
+        String containing path of file to be written, or file-like object, open
+        in binary write (`'wb'` mode, implementing the `write` method)
+    values : array-like
+        Surface morphometry values.  Shape must be (N,), (N, 1), (1, N) or (N,
+        1, 1)
+    fnum : int, optional
+        Number of faces in the associated surface.
+    """
+    magic_bytes = np.array([255, 255, 255], dtype=np.uint8)
+
+    vector = np.asarray(values)
+    vnum = np.prod(vector.shape)
+    if vector.shape not in ((vnum,), (vnum, 1), (1, vnum), (vnum, 1, 1)):
+        raise ValueError("Invalid shape: argument values must be a vector")
+
+    i4info = np.iinfo('i4')
+    if vnum > i4info.max:
+        raise ValueError("Too many values for morphometry file")
+    if not i4info.min <= fnum <= i4info.max:
+        raise ValueError("Argument fnum must be between {0} and {1}".format(
+                         i4info.min, i4info.max))
+
+    with Opener(file_like, 'wb') as fobj:
+        fobj.write(magic_bytes)
+
+        # vertex count, face count (unused), vals per vertex (only 1 supported)
+        fobj.write(np.array([vnum, fnum, 1], dtype='>i4'))
+
+        fobj.write(vector.astype('>f4'))
+
+
 def read_annot(filepath, orig_ids=False):
     """Read in a Freesurfer annotation from a .annot file.
 
@@ -305,20 +440,49 @@ def read_label(filepath, read_scalars=False):
     Parameters
     ----------
     filepath : str
-        Path to label file
-    read_scalars : bool
-        If true, read and return scalars associated with each vertex
+        Path to label file.
+    read_scalars : bool, optional
+        If True, read and return scalars associated with each vertex.
 
     Returns
     -------
     label_array : numpy array
-        Array with indices of vertices included in label
+        Array with indices of vertices included in label.
     scalar_array : numpy array (floats)
-        If read_scalars is True, array of scalar data for each vertex
-
+        Only returned if `read_scalars` is True.  Array of scalar data for each
+        vertex.
     """
     label_array = np.loadtxt(filepath, dtype=np.int, skiprows=2, usecols=[0])
     if read_scalars:
         scalar_array = np.loadtxt(filepath, skiprows=2, usecols=[-1])
         return label_array, scalar_array
     return label_array
+
+
+def _serialize_volume_info(volume_info):
+    """Helper for serializing the volume info."""
+    keys = ['head', 'valid', 'filename', 'volume', 'voxelsize', 'xras', 'yras',
+            'zras', 'cras']
+    diff = set(volume_info.keys()).difference(keys)
+    if len(diff) > 0:
+        raise ValueError('Invalid volume info: %s.' % diff.pop())
+
+    strings = list()
+    for key in keys:
+        if key == 'head':
+            if not (np.array_equal(volume_info[key], [20]) or np.array_equal(
+                    volume_info[key], [2, 0, 20])):
+                warnings.warn("Unknown extension code.")
+            strings.append(np.array(volume_info[key], dtype='>i4').tostring())
+        elif key in ('valid', 'filename'):
+            val = volume_info[key]
+            strings.append('{0} = {1}\n'.format(key, val).encode('utf-8'))
+        elif key == 'volume':
+            val = volume_info[key]
+            strings.append('{0} = {1} {2} {3}\n'.format(
+                key, val[0], val[1], val[2]).encode('utf-8'))
+        else:
+            val = volume_info[key]
+            strings.append('{0} = {1:0.10g} {2:0.10g} {3:0.10g}\n'.format(
+                key.ljust(6), val[0], val[1], val[2]).encode('utf-8'))
+    return b''.join(strings)
