@@ -14,26 +14,27 @@ import numpy as np
 
 from .externals.netcdf import netcdf_file
 
-from .spatialimages import Header, SpatialImage
+from .spatialimages import SpatialHeader, SpatialImage
 from .fileslice import canonical_slicers
 
 from .deprecated import FutureWarningMixin
 
 _dt_dict = {
-    ('b','unsigned'): np.uint8,
-    ('b','signed__'): np.int8,
-    ('c','unsigned'): 'S1',
-    ('h','unsigned'): np.uint16,
-    ('h','signed__'): np.int16,
-    ('i','unsigned'): np.uint32,
-    ('i','signed__'): np.int32,
-    }
+    ('b', 'unsigned'): np.uint8,
+    ('b', 'signed__'): np.int8,
+    ('c', 'unsigned'): 'S1',
+    ('h', 'unsigned'): np.uint16,
+    ('h', 'signed__'): np.int16,
+    ('i', 'unsigned'): np.uint32,
+    ('i', 'signed__'): np.int32,
+}
 
-# See https://en.wikibooks.org/wiki/MINC/Reference/MINC1-programmers-guide#MINC_specific_convenience_functions
+# See
+# https://en.wikibooks.org/wiki/MINC/Reference/MINC1-programmers-guide#MINC_specific_convenience_functions
 _default_dir_cos = {
-    'xspace': [1,0,0],
-    'yspace': [0,1,0],
-    'zspace': [0,0,1]}
+    'xspace': [1, 0, 0],
+    'yspace': [0, 1, 0],
+    'zspace': [0, 0, 1]}
 
 
 class MincError(Exception):
@@ -47,6 +48,7 @@ class Minc1File(object):
     this only when reading a MINC file, to pull out useful header
     information, and for the method of reading the data out
     '''
+
     def __init__(self, mincfile):
         self._mincfile = mincfile
         self._image = mincfile.variables['image']
@@ -62,7 +64,7 @@ class Minc1File(object):
             if dim.spacing != b'regular__':
                 raise ValueError('Irregular spacing not supported')
         self._spatial_dims = [name for name in self._dim_names
-                             if name.endswith('space')]
+                              if name.endswith('space')]
         # the MINC standard appears to allow the following variables to
         # be undefined.
         # https://en.wikibooks.org/wiki/MINC/Reference/MINC1-programmers-guide#Image_conversion_variables
@@ -101,7 +103,7 @@ class Minc1File(object):
         rot_mat = np.eye(nspatial)
         steps = np.zeros((nspatial,))
         starts = np.zeros((nspatial,))
-        dim_names = list(self._dim_names) # for indexing in loop
+        dim_names = list(self._dim_names)  # for indexing in loop
         for i, name in enumerate(self._spatial_dims):
             dim = self._dims[dim_names.index(name)]
             try:
@@ -112,7 +114,7 @@ class Minc1File(object):
             steps[i] = dim.step
             starts[i] = dim.start
         origin = np.dot(rot_mat, starts)
-        aff = np.eye(nspatial+1)
+        aff = np.eye(nspatial + 1)
         aff[:nspatial, :nspatial] = rot_mat * steps
         aff[:nspatial, nspatial] = origin
         return aff
@@ -160,8 +162,8 @@ class Minc1File(object):
         "max" and "min" of image over some dimensions of "image".
 
         The usual case is that "image" has dimensions ["zspace", "yspace",
-        "xspace"] and "image-max" has dimensions ["zspace"], but there can be up
-        to two dimensions for over which scaling is specified.
+        "xspace"] and "image-max" has dimensions ["zspace"], but there can be
+        up to two dimensions for over which scaling is specified.
 
         Parameters
         ----------
@@ -179,26 +181,25 @@ class Minc1File(object):
         mx_dims = self._get_dimensions(image_max)
         mn_dims = self._get_dimensions(image_min)
         if mx_dims != mn_dims:
-            raise MincError('"image-max" and "image-min" do not '
-                             'have the same dimensions')
+            raise MincError('"image-max" and "image-min" do not have the same'
+                            'dimensions')
         nscales = len(mx_dims)
         if nscales > 2:
             raise MincError('More than two scaling dimensions')
         if mx_dims != self._dim_names[:nscales]:
-            raise MincError('image-max and image dimensions '
-                            'do not match')
+            raise MincError('image-max and image dimensions do not match')
         dmin, dmax = self._get_valid_range()
         out_data = np.clip(data, dmin, dmax)
-        if nscales == 0: # scalar values
+        if nscales == 0:  # scalar values
             imax = self._get_scalar(image_max)
             imin = self._get_scalar(image_min)
-        else: # 1D or 2D array of scaling values
+        else:  # 1D or 2D array of scaling values
             # We need to get the correct values from image-max and image-min to
             # do the scaling.
             shape = self.get_data_shape()
             sliceobj = canonical_slicers(sliceobj, shape)
             # Indices into sliceobj referring to image axes
-            ax_inds = [i for i, obj in enumerate(sliceobj) if not obj is None]
+            ax_inds = [i for i, obj in enumerate(sliceobj) if obj is not None]
             assert len(ax_inds) == len(shape)
             # Slice imax, imin using same slicer as for data
             nscales_ax = ax_inds[nscales]
@@ -210,7 +211,7 @@ class Minc1File(object):
             i_slicer += broad_part
             imax = self._get_array(image_max)[i_slicer]
             imin = self._get_array(image_min)[i_slicer]
-        slope = (imax-imin) / (dmax-dmin)
+        slope = (imax - imin) / (dmax - dmin)
         inter = (imin - dmin * slope)
         out_data *= slope
         out_data += inter
@@ -234,7 +235,7 @@ class Minc1File(object):
         else:
             raw_data = self._image.data[sliceobj]
         dtype = self.get_data_dtype()
-        data =  np.asarray(raw_data).view(dtype)
+        data = np.asarray(raw_data).view(dtype)
         return self._normalize(data, sliceobj)
 
 
@@ -244,6 +245,7 @@ class MincImageArrayProxy(object):
     The array proxy allows us to freeze the passed fileobj and
     header such that it returns the expected data array.
     '''
+
     def __init__(self, minc_file):
         self.minc_file = minc_file
         self._shape = minc_file.get_data_shape()
@@ -265,7 +267,7 @@ class MincImageArrayProxy(object):
         return self.minc_file.get_scaled_data(sliceobj)
 
 
-class MincHeader(Header):
+class MincHeader(SpatialHeader):
     """ Class to contain header for MINC formats
     """
     # We don't use the data layout - this just in case we do later
@@ -280,6 +282,13 @@ class MincHeader(Header):
         raise NotImplementedError
 
 
+class Minc1Header(MincHeader):
+
+    @classmethod
+    def may_contain_header(klass, binaryblock):
+        return binaryblock[:4] == b'CDF\x01'
+
+
 class Minc1Image(SpatialImage):
     ''' Class for MINC1 format images
 
@@ -287,9 +296,14 @@ class Minc1Image(SpatialImage):
     MINC header type - and reads the relevant information from the MINC file on
     load.
     '''
-    header_class = MincHeader
+    header_class = Minc1Header
+    _meta_sniff_len = 4
+    valid_exts = ('.mnc',)
     files_types = (('image', '.mnc'),)
-    _compressed_exts = ('.gz', '.bz2')
+    _compressed_suffixes = ('.gz', '.bz2')
+
+    makeable = True
+    rw = False
 
     ImageArrayProxy = MincImageArrayProxy
 
@@ -310,11 +324,14 @@ class Minc1Image(SpatialImage):
 
 load = Minc1Image.load
 
+
 # Backwards compatibility
 class MincFile(FutureWarningMixin, Minc1File):
     """ Deprecated alternative name for Minc1File
     """
     warn_message = 'MincFile is deprecated; please use Minc1File instead'
+
+
 class MincImage(FutureWarningMixin, Minc1Image):
     """ Deprecated alternative name for Minc1Image
     """
