@@ -12,6 +12,7 @@ NIfTI1 format defined at http://nifti.nimh.nih.gov/nifti-1/
 '''
 from __future__ import division, print_function
 import warnings
+from io import BytesIO
 
 import numpy as np
 import numpy.linalg as npl
@@ -21,57 +22,58 @@ from .volumeutils import Recoder, make_dt_codes, endian_codes
 from .spatialimages import HeaderDataError, ImageFileError
 from .batteryrunners import Report
 from .quaternions import fillpositive, quat2mat, mat2quat
-from . import analyze # module import
+from . import analyze  # module import
 from .spm99analyze import SpmAnalyzeHeader
 from .casting import have_binary128
+from .pydicom_compat import have_dicom, pydicom as pdcm
 
 # nifti1 flat header definition for Analyze-like first 348 bytes
 # first number in comments indicates offset in file header in bytes
 header_dtd = [
-    ('sizeof_hdr', 'i4'), # 0; must be 348
-    ('data_type', 'S10'), # 4; unused
-    ('db_name', 'S18'),   # 14; unused
-    ('extents', 'i4'),    # 32; unused
-    ('session_error', 'i2'), # 36; unused
-    ('regular', 'S1'),    # 38; unused
-    ('dim_info', 'u1'),   # 39; MRI slice ordering code
-    ('dim', 'i2', (8,)),     # 40; data array dimensions
-    ('intent_p1', 'f4'),  # 56; first intent parameter
-    ('intent_p2', 'f4'),  # 60; second intent parameter
-    ('intent_p3', 'f4'),  # 64; third intent parameter
-    ('intent_code', 'i2'),# 68; NIFTI intent code
-    ('datatype', 'i2'),   # 70; it's the datatype
-    ('bitpix', 'i2'),     # 72; number of bits per voxel
-    ('slice_start', 'i2'),# 74; first slice index
-    ('pixdim', 'f4', (8,)),  # 76; grid spacings (units below)
-    ('vox_offset', 'f4'), # 108; offset to data in image file
-    ('scl_slope', 'f4'),  # 112; data scaling slope
-    ('scl_inter', 'f4'),  # 116; data scaling intercept
-    ('slice_end', 'i2'),  # 120; last slice index
-    ('slice_code', 'u1'), # 122; slice timing order
-    ('xyzt_units', 'u1'), # 123; units of pixdim[1..4]
-    ('cal_max', 'f4'),    # 124; max display intensity
-    ('cal_min', 'f4'),    # 128; min display intensity
-    ('slice_duration', 'f4'), # 132; time for 1 slice
-    ('toffset', 'f4'),   # 136; time axis shift
-    ('glmax', 'i4'),     # 140; unused
-    ('glmin', 'i4'),     # 144; unused
-    ('descrip', 'S80'),  # 148; any text
-    ('aux_file', 'S24'), # 228; auxiliary filename
-    ('qform_code', 'i2'), # 252; xform code
-    ('sform_code', 'i2'), # 254; xform code
-    ('quatern_b', 'f4'), # 256; quaternion b param
-    ('quatern_c', 'f4'), # 260; quaternion c param
-    ('quatern_d', 'f4'), # 264; quaternion d param
-    ('qoffset_x', 'f4'), # 268; quaternion x shift
-    ('qoffset_y', 'f4'), # 272; quaternion y shift
-    ('qoffset_z', 'f4'), # 276; quaternion z shift
-    ('srow_x', 'f4', (4,)), # 280; 1st row affine transform
-    ('srow_y', 'f4', (4,)), # 296; 2nd row affine transform
-    ('srow_z', 'f4', (4,)), # 312; 3rd row affine transform
-    ('intent_name', 'S16'), # 328; name or meaning of data
-    ('magic', 'S4')      # 344; must be 'ni1\0' or 'n+1\0'
-    ]
+    ('sizeof_hdr', 'i4'),      # 0; must be 348
+    ('data_type', 'S10'),      # 4; unused
+    ('db_name', 'S18'),        # 14; unused
+    ('extents', 'i4'),         # 32; unused
+    ('session_error', 'i2'),   # 36; unused
+    ('regular', 'S1'),         # 38; unused
+    ('dim_info', 'u1'),        # 39; MRI slice ordering code
+    ('dim', 'i2', (8,)),       # 40; data array dimensions
+    ('intent_p1', 'f4'),       # 56; first intent parameter
+    ('intent_p2', 'f4'),       # 60; second intent parameter
+    ('intent_p3', 'f4'),       # 64; third intent parameter
+    ('intent_code', 'i2'),     # 68; NIFTI intent code
+    ('datatype', 'i2'),        # 70; it's the datatype
+    ('bitpix', 'i2'),          # 72; number of bits per voxel
+    ('slice_start', 'i2'),     # 74; first slice index
+    ('pixdim', 'f4', (8,)),    # 76; grid spacings (units below)
+    ('vox_offset', 'f4'),      # 108; offset to data in image file
+    ('scl_slope', 'f4'),       # 112; data scaling slope
+    ('scl_inter', 'f4'),       # 116; data scaling intercept
+    ('slice_end', 'i2'),       # 120; last slice index
+    ('slice_code', 'u1'),      # 122; slice timing order
+    ('xyzt_units', 'u1'),      # 123; units of pixdim[1..4]
+    ('cal_max', 'f4'),         # 124; max display intensity
+    ('cal_min', 'f4'),         # 128; min display intensity
+    ('slice_duration', 'f4'),  # 132; time for 1 slice
+    ('toffset', 'f4'),         # 136; time axis shift
+    ('glmax', 'i4'),           # 140; unused
+    ('glmin', 'i4'),           # 144; unused
+    ('descrip', 'S80'),        # 148; any text
+    ('aux_file', 'S24'),       # 228; auxiliary filename
+    ('qform_code', 'i2'),      # 252; xform code
+    ('sform_code', 'i2'),      # 254; xform code
+    ('quatern_b', 'f4'),       # 256; quaternion b param
+    ('quatern_c', 'f4'),       # 260; quaternion c param
+    ('quatern_d', 'f4'),       # 264; quaternion d param
+    ('qoffset_x', 'f4'),       # 268; quaternion x shift
+    ('qoffset_y', 'f4'),       # 272; quaternion y shift
+    ('qoffset_z', 'f4'),       # 276; quaternion z shift
+    ('srow_x', 'f4', (4,)),    # 280; 1st row affine transform
+    ('srow_y', 'f4', (4,)),    # 296; 2nd row affine transform
+    ('srow_z', 'f4', (4,)),    # 312; 3rd row affine transform
+    ('intent_name', 'S16'),    # 328; name or meaning of data
+    ('magic', 'S4')            # 344; must be 'ni1\0' or 'n+1\0'
+]
 
 # Full header numpy dtype
 header_dtype = np.dtype(header_dtd)
@@ -85,7 +87,7 @@ else:
     _float128t = np.void
     _complex256t = np.void
 
-_dtdefs = ( # code, label, dtype definition, niistring
+_dtdefs = (  # code, label, dtype definition, niistring
     (0, 'none', np.void, ""),
     (1, 'binary', np.void, ""),
     (2, 'uint8', np.uint8, "NIFTI_TYPE_UINT8"),
@@ -94,38 +96,37 @@ _dtdefs = ( # code, label, dtype definition, niistring
     (16, 'float32', np.float32, "NIFTI_TYPE_FLOAT32"),
     (32, 'complex64', np.complex64, "NIFTI_TYPE_COMPLEX64"),
     (64, 'float64', np.float64, "NIFTI_TYPE_FLOAT64"),
-    (128, 'RGB', np.dtype([('R','u1'),
-                  ('G', 'u1'),
-                  ('B', 'u1')]), "NIFTI_TYPE_RGB24"),
+    (128, 'RGB', np.dtype([('R', 'u1'),
+                           ('G', 'u1'),
+                           ('B', 'u1')]), "NIFTI_TYPE_RGB24"),
     (255, 'all', np.void, ''),
     (256, 'int8', np.int8, "NIFTI_TYPE_INT8"),
     (512, 'uint16', np.uint16, "NIFTI_TYPE_UINT16"),
     (768, 'uint32', np.uint32, "NIFTI_TYPE_UINT32"),
-    (1024,'int64', np.int64, "NIFTI_TYPE_INT64"),
+    (1024, 'int64', np.int64, "NIFTI_TYPE_INT64"),
     (1280, 'uint64', np.uint64, "NIFTI_TYPE_UINT64"),
     (1536, 'float128', _float128t, "NIFTI_TYPE_FLOAT128"),
     (1792, 'complex128', np.complex128, "NIFTI_TYPE_COMPLEX128"),
     (2048, 'complex256', _complex256t, "NIFTI_TYPE_COMPLEX256"),
-    (2304, 'RGBA', np.dtype([('R','u1'),
-                    ('G', 'u1'),
-                    ('B', 'u1'),
-                    ('A', 'u1')]), "NIFTI_TYPE_RGBA32"),
-    )
+    (2304, 'RGBA', np.dtype([('R', 'u1'),
+                             ('G', 'u1'),
+                             ('B', 'u1'),
+                             ('A', 'u1')]), "NIFTI_TYPE_RGBA32"),
+)
 
 # Make full code alias bank, including dtype column
 data_type_codes = make_dt_codes(_dtdefs)
 
 # Transform (qform, sform) codes
-xform_codes = Recoder(( # code, label, niistring
-                       (0, 'unknown', "NIFTI_XFORM_UNKNOWN"),
-                       (1, 'scanner', "NIFTI_XFORM_SCANNER_ANAT"),
-                       (2, 'aligned', "NIFTI_XFORM_ALIGNED_ANAT"),
-                       (3, 'talairach', "NIFTI_XFORM_TALAIRACH"),
-                       (4, 'mni', "NIFTI_XFORM_MNI_152")),
-                      fields=('code', 'label', 'niistring'))
+xform_codes = Recoder((  # code, label, niistring
+    (0, 'unknown', "NIFTI_XFORM_UNKNOWN"),
+    (1, 'scanner', "NIFTI_XFORM_SCANNER_ANAT"),
+    (2, 'aligned', "NIFTI_XFORM_ALIGNED_ANAT"),
+    (3, 'talairach', "NIFTI_XFORM_TALAIRACH"),
+    (4, 'mni', "NIFTI_XFORM_MNI_152")), fields=('code', 'label', 'niistring'))
 
 # unit codes
-unit_codes = Recoder(( # code, label
+unit_codes = Recoder((  # code, label
     (0, 'unknown'),
     (1, 'meter'),
     (2, 'mm'),
@@ -137,23 +138,21 @@ unit_codes = Recoder(( # code, label
     (40, 'ppm'),
     (48, 'rads')), fields=('code', 'label'))
 
-slice_order_codes = Recoder(( # code, label
+slice_order_codes = Recoder((  # code, label
     (0, 'unknown'),
     (1, 'sequential increasing', 'seq inc'),
     (2, 'sequential decreasing', 'seq dec'),
     (3, 'alternating increasing', 'alt inc'),
     (4, 'alternating decreasing', 'alt dec'),
     (5, 'alternating increasing 2', 'alt inc 2'),
-    (6, 'alternating decreasing 2', 'alt dec 2')),
-                            fields=('code', 'label'))
+    (6, 'alternating decreasing 2', 'alt dec 2')), fields=('code', 'label'))
 
 intent_codes = Recoder((
     # code, label, parameters description tuple
     (0, 'none', (), "NIFTI_INTENT_NONE"),
-    (2, 'correlation',('p1 = DOF',), "NIFTI_INTENT_CORREL"),
+    (2, 'correlation', ('p1 = DOF',), "NIFTI_INTENT_CORREL"),
     (3, 't test', ('p1 = DOF',), "NIFTI_INTENT_TTEST"),
-    (4, 'f test',
-     ('p1 = numerator DOF', 'p2 = denominator DOF'),
+    (4, 'f test', ('p1 = numerator DOF', 'p2 = denominator DOF'),
      "NIFTI_INTENT_FTEST"),
     (5, 'z score', (), "NIFTI_INTENT_ZSCORE"),
     (6, 'chi2', ('p1 = DOF',), "NIFTI_INTENT_CHISQ"),
@@ -166,7 +165,7 @@ intent_codes = Recoder((
      ('p1 = number of trials', 'p2 = probability per trial'),
      "NIFTI_INTENT_BINOM"),
     # 2 parameter gamma
-    # Density(x) proportional to # x^(p1-1) * exp(-p2*x)
+    # Density(x) proportional to  # x^(p1-1) * exp(-p2*x)
     (9, 'gamma',
      ('p1 = shape, p2 = scale', 2),
      "NIFTI_INTENT_GAMMA"),
@@ -182,7 +181,7 @@ intent_codes = Recoder((
       'p3 = numerator noncentrality parameter',),
      "NIFTI_INTENT_FTEST_NONC"),
     (13, 'non central chi2',
-     ('p1 = DOF', 'p2 = noncentrality parameter',), 
+     ('p1 = DOF', 'p2 = noncentrality parameter',),
      "NIFTI_INTENT_CHISQ_NONC"),
     (14, 'logistic',
      ('p1 = location', 'p2 = scale',),
@@ -228,13 +227,13 @@ intent_codes = Recoder((
     (2001, 'time series',
      (),
      "NIFTI_INTENT_TIME_SERIES",
-     "NIFTI_INTENT_TIMESERIES"), # this mis-spell occurs in the wild
+     "NIFTI_INTENT_TIMESERIES"),  # this mis-spell occurs in the wild
     (2002, 'node index', (), "NIFTI_INTENT_NODE_INDEX"),
     (2003, 'rgb vector', (), "NIFTI_INTENT_RGB_VECTOR"),
     (2004, 'rgba vector', (), "NIFTI_INTENT_RGBA_VECTOR"),
     (2005, 'shape', (), "NIFTI_INTENT_SHAPE"),
-    # The codes below appear on the CIFTI page, but don't appear to have reached
-    # the nifti standard as of 19 August 2013
+    # The codes below appear on the CIFTI page, but don't appear to have
+    # reached the nifti standard as of 19 August 2013
     # https://www.nitrc.org/plugins/mwiki/index.php/cifti:ConnectivityMatrixFileFormats
     (3001, 'dense connectivity', (), 'NIFTI_INTENT_CONNECTIVITY_DENSE'),
     (3002, 'dense time connectivity', (),
@@ -245,7 +244,7 @@ intent_codes = Recoder((
      "NIFTI_INTENT_CONNECTIVITY_PARCELLATED_TIME"),
     (3005, 'trajectory connectivity', (),
      'NIFTI_INTENT_CONNECTIVITY_CONNECTIVITY_TRAJECTORY'),
-    ), fields=('code', 'label', 'parameters', 'niistring'))
+), fields=('code', 'label', 'parameters', 'niistring'))
 
 
 class Nifti1Extension(object):
@@ -255,11 +254,12 @@ class Nifti1Extension(object):
     as `comment`. More sophisticated extensions should/will be supported by
     dedicated subclasses.
     """
+
     def __init__(self, code, content):
         """
         Parameters
         ----------
-        code : int|str
+        code : int or str
           Canonical extension code as defined in the NIfTI standard, given
           either as integer or corresponding label
           (see :data:`~nibabel.nifti1.extension_codes`)
@@ -381,13 +381,101 @@ class Nifti1Extension(object):
         fileobj.write(b'\x00' * (extstart + rawsize - fileobj.tell()))
 
 
+class Nifti1DicomExtension(Nifti1Extension):
+    """NIfTI1 DICOM header extension
+
+    This class is a thin wrapper around pydicom to read a binary DICOM
+    byte string. If pydicom is available, content is exposed as a Dicom Dataset.
+    Otherwise, this silently falls back to the standard NiftiExtension class
+    and content is the raw bytestring loaded directly from the nifti file
+    header.
+    """
+    def __init__(self, code, content, parent_hdr=None):
+        """
+        Parameters
+        ----------
+        code : int or str
+          Canonical extension code as defined in the NIfTI standard, given
+          either as integer or corresponding label
+          (see :data:`~nibabel.nifti1.extension_codes`)
+        content : bytes or pydicom Dataset or None
+          Extension content - either a bytestring as read from the NIfTI file
+          header or an existing pydicom Dataset. If a bystestring, the content
+          is converted into a Dataset on initialization. If None, a new empty
+          Dataset is created.
+        parent_hdr : :class:`~nibabel.nifti1.Nifti1Header`, optional
+          If a dicom extension belongs to an existing
+          :class:`~nibabel.nifti1.Nifti1Header`, it may be provided here to
+          ensure that the DICOM dataset is written with correctly corresponding
+          endianness; otherwise it is assumed the dataset is little endian.
+
+        Notes
+        -----
+
+        code should always be 2 for DICOM.
+        """
+
+        self._code = code
+        if parent_hdr:
+            self._is_little_endian = parent_hdr.endianness == '<'
+        else:
+            self._is_little_endian = True
+        if isinstance(content, pdcm.dataset.Dataset):
+            self._is_implicit_VR = False
+            self._raw_content = self._mangle(content)
+            self._content = content
+        elif isinstance(content, bytes):  # Got a byte string - unmangle it
+            self._raw_content = content
+            self._is_implicit_VR = self._guess_implicit_VR()
+            ds = self._unmangle(content, self._is_implicit_VR,
+                                self._is_little_endian)
+            self._content = ds
+        elif content is None:  # initialize a new dicom dataset
+            self._is_implicit_VR = False
+            self._content = pdcm.dataset.Dataset()
+        else:
+            raise TypeError("content must be either a bytestring or a pydicom "
+                            "Dataset. Got %s" % content.__class__)
+
+    def _guess_implicit_VR(self):
+        """Try to guess DICOM syntax by checking for valid VRs.
+
+        Without a DICOM Transfer Syntax, it's difficult to tell if Value
+        Representations (VRs) are included in the DICOM encoding or not.
+        This reads where the first VR would be and checks it against a list of
+        valid VRs
+        """
+        potential_vr = self._raw_content[4:6].decode()
+        if potential_vr in pdcm.values.converters.keys():
+            implicit_VR = False
+        else:
+            implicit_VR = True
+        return implicit_VR
+
+    def _unmangle(self, value, is_implicit_VR=False, is_little_endian=True):
+        bio = BytesIO(value)
+        ds = pdcm.filereader.read_dataset(bio,
+                                          is_implicit_VR,
+                                          is_little_endian)
+        return ds
+
+    def _mangle(self, dataset):
+        bio = BytesIO()
+        dio = pdcm.filebase.DicomFileLike(bio)
+        dio.is_implicit_VR = self._is_implicit_VR
+        dio.is_little_endian = self._is_little_endian
+        ds_len = pdcm.filewriter.write_dataset(dio, dataset)
+        dio.seek(0)
+        return dio.read(ds_len)
+
+
 # NIfTI header extension type codes (ECODE)
 # see nifti1_io.h for a complete list of all known extensions and
 # references to their description or contacts of the respective
 # initiators
 extension_codes = Recoder((
     (0, "ignore", Nifti1Extension),
-    (2, "dicom", Nifti1Extension),
+    (2, "dicom", Nifti1DicomExtension if have_dicom else Nifti1Extension),
     (4, "afni", Nifti1Extension),
     (6, "comment", Nifti1Extension),
     (8, "xcede", Nifti1Extension),
@@ -395,13 +483,14 @@ extension_codes = Recoder((
     (12, "workflow_fwds", Nifti1Extension),
     (14, "freesurfer", Nifti1Extension),
     (16, "pypickle", Nifti1Extension)
-    ),
+),
     fields=('code', 'label', 'handler'))
 
 
 class Nifti1Extensions(list):
     """Simple extension collection, implemented as a list-subclass.
     """
+
     def count(self, ecode):
         """Returns the number of extensions matching a given *ecode*.
 
@@ -427,8 +516,7 @@ class Nifti1Extensions(list):
         return np.sum([e.get_sizeondisk() for e in self])
 
     def __repr__(self):
-        s = "Nifti1Extensions(%s)" \
-                % ', '.join([str(e) for e in self])
+        s = "Nifti1Extensions(%s)" % ', '.join(str(e) for e in self)
         return s
 
     def __cmp__(self, other):
@@ -584,7 +672,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         '''
         return self.__class__(
             self.binaryblock,
-            self.endianness, 
+            self.endianness,
             False,
             self.extensions)
 
@@ -603,10 +691,11 @@ class Nifti1Header(SpmAnalyzeHeader):
         # If this is a detached header file read to end
         if not klass.is_single:
             extsize = -1
-        else: # otherwise read until the beginning of the data
+        else:  # otherwise read until the beginning of the data
             extsize = hdr._structarr['vox_offset'] - fileobj.tell()
         byteswap = endian_codes['native'] != hdr.endianness
-        hdr.extensions = klass.exts_klass.from_fileobj(fileobj, extsize, byteswap)
+        hdr.extensions = klass.exts_klass.from_fileobj(fileobj, extsize,
+                                                       byteswap)
         return hdr
 
     def write_to(self, fileobj):
@@ -615,7 +704,7 @@ class Nifti1Header(SpmAnalyzeHeader):
             vox_offset = self._structarr['vox_offset']
             min_vox_offset = (self.single_vox_offset +
                               self.extensions.get_sizeondisk())
-            if vox_offset == 0: # vox offset unset; set as necessary
+            if vox_offset == 0:  # vox offset unset; set as necessary
                 self._structarr['vox_offset'] = min_vox_offset
             elif vox_offset < min_vox_offset:
                 raise HeaderDataError(
@@ -656,7 +745,8 @@ class Nifti1Header(SpmAnalyzeHeader):
     def from_header(klass, header=None, check=True):
         ''' Class method to create header from another header
 
-        Extend Analyze header copy by copying extensions from other Nifti types.
+        Extend Analyze header copy by copying extensions from other Nifti
+        types.
 
         Parameters
         ----------
@@ -716,7 +806,7 @@ class Nifti1Header(SpmAnalyzeHeader):
             return shape
 
     def set_data_shape(self, shape):
-        ''' Set shape of data
+        ''' Set shape of data  # noqa
 
         If ``ndims == len(shape)`` then we set zooms for dimensions higher than
         ``ndims`` to 1.0
@@ -758,9 +848,12 @@ class Nifti1Header(SpmAnalyzeHeader):
 
         .. _issue 100: https://github.com/nipy/nibabel/issues/100
         .. _issue 309: https://github.com/nipy/nibabel/issues/309
-        .. _save77: https://code.google.com/p/fieldtrip/source/browse/trunk/external/freesurfer/save_nifti.m?spec=svn8776&r=8776#77
-        .. _save50: https://code.google.com/p/fieldtrip/source/browse/trunk/external/freesurfer/save_nifti.m?spec=svn8776&r=8776#50
-        .. _load_nifti.m: https://code.google.com/p/fieldtrip/source/browse/trunk/external/freesurfer/load_nifti.m?spec=svn8776&r=8776#86
+        .. _save77:
+            https://github.com/fieldtrip/fieldtrip/blob/428798b/external/freesurfer/save_nifti.m#L77-L82
+        .. _save50:
+            https://github.com/fieldtrip/fieldtrip/blob/428798b/external/freesurfer/save_nifti.m#L50-L56
+        .. _load_nifti.m:
+            https://github.com/fieldtrip/fieldtrip/blob/428798b/external/freesurfer/load_nifti.m#L86-L89
         .. _standard header: http://nifti.nimh.nih.gov/pub/dist/src/niftilib/nifti1.h
         '''
         hdr = self._structarr
@@ -779,8 +872,8 @@ class Nifti1Header(SpmAnalyzeHeader):
             else:
                 overflow = hdr['glmin'] != shape[0]
             if overflow:
-                raise HeaderDataError('shape[0] %s does not fit in glmax datatype' %
-                                      shape[0])
+                raise HeaderDataError('shape[0] %s does not fit in glmax '
+                                      'datatype' % shape[0])
             warnings.warn('Using large vector Freesurfer hack; header will '
                           'not be compatible with SPM or FSL', stacklevel=2)
             shape = (-1, 1, 1) + shape[3:]
@@ -803,8 +896,8 @@ class Nifti1Header(SpmAnalyzeHeader):
         ----------
         coded : bool, optional
             If True, return {affine or None}, and qform code.  If False, just
-            return affine.  {affine or None} means, return None if qform code ==
-            0, and affine otherwise.
+            return affine.  {affine or None} means, return None if qform code
+            == 0, and affine otherwise.
 
         Returns
         -------
@@ -871,7 +964,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         Examples
         --------
         >>> hdr = Nifti1Header()
-        >>> int(hdr['qform_code']) # gives 0 - unknown
+        >>> int(hdr['qform_code'])  # gives 0 - unknown
         0
         >>> affine = np.diag([1,2,3,1])
         >>> np.all(hdr.get_qform() == affine)
@@ -879,7 +972,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         >>> hdr.set_qform(affine)
         >>> np.all(hdr.get_qform() == affine)
         True
-        >>> int(hdr['qform_code']) # gives 2 - aligned
+        >>> int(hdr['qform_code'])  # gives 2 - aligned
         2
         >>> hdr.set_qform(affine, code='talairach')
         >>> int(hdr['qform_code'])
@@ -900,10 +993,10 @@ class Nifti1Header(SpmAnalyzeHeader):
             if affine is None:
                 code = 0
             elif old_code == 0:
-                code = 2 # aligned
+                code = 2  # aligned
             else:
                 code = old_code
-        else: # code set
+        else:  # code set
             code = self._field_recoders['qform_code'][code]
         hdr['qform_code'] = code
         if affine is None:
@@ -946,8 +1039,8 @@ class Nifti1Header(SpmAnalyzeHeader):
         ----------
         coded : bool, optional
             If True, return {affine or None}, and sform code.  If False, just
-            return affine.  {affine or None} means, return None if sform code ==
-            0, and affine otherwise.
+            return affine.  {affine or None} means, return None if sform code
+            == 0, and affine otherwise.
 
         Returns
         -------
@@ -990,7 +1083,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         Examples
         --------
         >>> hdr = Nifti1Header()
-        >>> int(hdr['sform_code']) # gives 0 - unknown
+        >>> int(hdr['sform_code'])  # gives 0 - unknown
         0
         >>> affine = np.diag([1,2,3,1])
         >>> np.all(hdr.get_sform() == affine)
@@ -998,7 +1091,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         >>> hdr.set_sform(affine)
         >>> np.all(hdr.get_sform() == affine)
         True
-        >>> int(hdr['sform_code']) # gives 2 - aligned
+        >>> int(hdr['sform_code'])  # gives 2 - aligned
         2
         >>> hdr.set_sform(affine, code='talairach')
         >>> int(hdr['sform_code'])
@@ -1019,10 +1112,10 @@ class Nifti1Header(SpmAnalyzeHeader):
             if affine is None:
                 code = 0
             elif old_code == 0:
-                code = 2 # aligned
+                code = 2  # aligned
             else:
                 code = old_code
-        else: # code set
+        else:  # code set
             code = self._field_recoders['sform_code'][code]
         hdr['sform_code'] = code
         if affine is None:
@@ -1038,10 +1131,11 @@ class Nifti1Header(SpmAnalyzeHeader):
         Returns
         -------
         slope : None or float
-           scaling (slope).  None if there is no valid scaling from these fields
+           scaling (slope).  None if there is no valid scaling from these
+           fields
         inter : None or float
-           offset (intercept). None if there is no valid scaling or if offset is
-           not finite.
+           offset (intercept). None if there is no valid scaling or if offset
+           is not finite.
 
         Examples
         --------
@@ -1140,9 +1234,9 @@ class Nifti1Header(SpmAnalyzeHeader):
         freq = info & 3
         phase = (info >> 2) & 3
         slice = (info >> 4) & 3
-        return (freq-1 if freq else None,
-            phase-1 if phase else None,
-            slice-1 if slice else None)
+        return (freq - 1 if freq else None,
+                phase - 1 if phase else None,
+                slice - 1 if slice else None)
 
     def set_dim_info(self, freq=None, phase=None, slice=None):
         ''' Sets nifti MRI slice etc dimension information
@@ -1182,12 +1276,12 @@ class Nifti1Header(SpmAnalyzeHeader):
             if inp not in (None, 0, 1, 2):
                 raise HeaderDataError('Inputs must be in [None, 0, 1, 2]')
         info = 0
-        if not freq is None:
-            info = info | ((freq+1) & 3)
-        if not phase is None:
-            info = info | (((phase+1) & 3) << 2)
-        if not slice is None:
-            info = info | (((slice+1) & 3) << 4)
+        if freq is not None:
+            info = info | ((freq + 1) & 3)
+        if phase is not None:
+            info = info | (((phase + 1) & 3) << 2)
+        if slice is not None:
+            info = info | (((slice + 1) & 3) << 4)
         self._structarr['dim_info'] = info
 
     def get_intent(self, code_repr='label'):
@@ -1227,7 +1321,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         else:
             raise TypeError('repr can be "label" or "code"')
         n_params = len(recoder.parameters[code])
-        params = (float(hdr['intent_p%d' % (i+1)]) for i in range(n_params))
+        params = (float(hdr['intent_p%d' % (i + 1)]) for i in range(n_params))
         name = asstr(np.asscalar(hdr['intent_name']))
         return label, tuple(params), name
 
@@ -1258,7 +1352,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         Examples
         --------
         >>> hdr = Nifti1Header()
-        >>> hdr.set_intent(0) # unknown code
+        >>> hdr.set_intent(0)  # unknown code
         >>> hdr.set_intent('z score')
         >>> hdr.get_intent()
         ('z score', (), '')
@@ -1283,7 +1377,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         all_params = [0] * 3
         all_params[:len(params)] = params[:]
         for i, param in enumerate(all_params):
-            hdr['intent_p%d' % (i+1)] = param
+            hdr['intent_p%d' % (i + 1)] = param
         hdr['intent_code'] = icode
         hdr['intent_name'] = name
 
@@ -1335,7 +1429,6 @@ class Nifti1Header(SpmAnalyzeHeader):
     def get_n_slices(self):
         ''' Return the number of slices
         '''
-        hdr = self._structarr
         _, _, slice_dim = self.get_dim_info()
         if slice_dim is None:
             raise HeaderDataError('Slice dimension not set in header '
@@ -1385,15 +1478,15 @@ class Nifti1Header(SpmAnalyzeHeader):
         if slice_start < 0:
             raise HeaderDataError('slice_start should be >= 0')
         if slice_end == 0:
-            slice_end = slice_len-1
+            slice_end = slice_len - 1
         n_timed = slice_end - slice_start + 1
         if n_timed < 1:
             raise HeaderDataError('slice_end should be > slice_start')
         st_order = self._slice_time_order(slabel, n_timed)
         times = st_order * duration
-        return ((None,)*slice_start +
+        return ((None,) * slice_start +
                 tuple(times) +
-                (None,)*(slice_len-slice_end-1))
+                (None,) * (slice_len - slice_end - 1))
 
     def set_slice_times(self, slice_times):
         ''' Set slice times into *hdr*
@@ -1434,9 +1527,9 @@ class Nifti1Header(SpmAnalyzeHeader):
             raise HeaderDataError('Not all slice times can be None')
         for ind, time in enumerate(slice_times[::-1]):
             if time is not None:
-                slice_end = slice_len-ind-1
+                slice_end = slice_len - ind - 1
                 break
-        timed = slice_times[slice_start:slice_end+1]
+        timed = slice_times[slice_start:slice_end + 1]
         for time in timed:
             if time is None:
                 raise HeaderDataError('Cannot have None in middle '
@@ -1480,7 +1573,7 @@ class Nifti1Header(SpmAnalyzeHeader):
                                  list(range(1, n_slices, 2)))
         elif slabel == 'alternating decreasing':
             sp_ind_time_order = (list(range(n_slices - 1, -1, -2)) +
-                                 list(range(n_slices -2 , -1, -2)))
+                                 list(range(n_slices - 2, -1, -2)))
         elif slabel == 'alternating increasing 2':
             sp_ind_time_order = (list(range(1, n_slices, 2)) +
                                  list(range(0, n_slices, 2)))
@@ -1556,7 +1649,7 @@ class Nifti1Header(SpmAnalyzeHeader):
         if magic in (hdr.pair_magic, hdr.single_magic):
             return hdr, rep
         rep.problem_msg = ('magic string "%s" is not valid' %
-                            asstr(magic))
+                           asstr(magic))
         rep.problem_level = 45
         if fix:
             rep.fix_msg = 'leaving as is, but future errors are likely'
@@ -1613,6 +1706,15 @@ class Nifti1Header(SpmAnalyzeHeader):
             rep.fix_msg = 'setting to 0'
         return hdr, rep
 
+    @classmethod
+    def may_contain_header(klass, binaryblock):
+        if len(binaryblock) < klass.sizeof_hdr:
+            return False
+
+        hdr_struct = np.ndarray(shape=(), dtype=header_dtype,
+                                buffer=binaryblock[:klass.sizeof_hdr])
+        return hdr_struct['magic'] in (b'ni1', b'n+1')
+
 
 class Nifti1PairHeader(Nifti1Header):
     ''' Class for NIfTI1 pair header '''
@@ -1624,6 +1726,8 @@ class Nifti1Pair(analyze.AnalyzeImage):
     """ Class for NIfTI1 format image, header pair
     """
     header_class = Nifti1PairHeader
+    _meta_sniff_len = header_class.sizeof_hdr
+    rw = True
 
     def __init__(self, dataobj, affine, header=None,
                  extra=None, file_map=None):
@@ -1633,7 +1737,7 @@ class Nifti1Pair(analyze.AnalyzeImage):
                                          extra,
                                          file_map)
         # Force set of s/q form when header is None unless affine is also None
-        if header is None and not affine is None:
+        if header is None and affine is not None:
             self._affine2header()
     # Copy docstring
     __init__.doc = analyze.AnalyzeImage.__init__.__doc__
@@ -1760,8 +1864,8 @@ class Nifti1Pair(analyze.AnalyzeImage):
         ----------
         coded : bool, optional
             If True, return {affine or None}, and sform code.  If False, just
-            return affine.  {affine or None} means, return None if sform code ==
-            0, and affine otherwise.
+            return affine.  {affine or None} means, return None if sform code
+            == 0, and affine otherwise.
 
         Returns
         -------
@@ -1847,14 +1951,15 @@ class Nifti1Image(Nifti1Pair):
     """ Class for single file NIfTI1 format image
     """
     header_class = Nifti1Header
+    valid_exts = ('.nii',)
     files_types = (('image', '.nii'),)
 
     @staticmethod
     def _get_fileholders(file_map):
         """ Return fileholder for header and image
 
-        For single-file niftis, the fileholder for the header and the image will
-        be the same
+        For single-file niftis, the fileholder for the header and the image
+        will be the same
         """
         return file_map['image'], file_map['image']
 
