@@ -112,51 +112,45 @@ carry the position at which a write (with ``to_files``) should place the
 data.  The ``file_map`` contents should therefore be such, that this will
 work:
 
-   >>> # write an image to files
-   >>> from io import BytesIO
-   >>> file_map = nib.AnalyzeImage.make_file_map()
-   >>> file_map['image'].fileobj = BytesIO()
-   >>> file_map['header'].fileobj = BytesIO()
-   >>> img = nib.AnalyzeImage(data, np.eye(4))
-   >>> img.file_map = file_map
-   >>> img.to_file_map()
-   >>> # read it back again from the written files
-   >>> img2 = nib.AnalyzeImage.from_file_map(file_map)
-   >>> np.all(img2.get_data() == data)
-   True
-   >>> # write, read it again
-   >>> img2.to_file_map()
-   >>> img3 = nib.AnalyzeImage.from_file_map(file_map)
-   >>> np.all(img3.get_data() == data)
-   True
+    >>> # write an image to files
+    >>> from io import BytesIO
+    >>> import nibabel as nib
+    >>> file_map = nib.AnalyzeImage.make_file_map()
+    >>> file_map['image'].fileobj = BytesIO()
+    >>> file_map['header'].fileobj = BytesIO()
+    >>> img = nib.AnalyzeImage(data, np.eye(4))
+    >>> img.file_map = file_map
+    >>> img.to_file_map()
+    >>> # read it back again from the written files
+    >>> img2 = nib.AnalyzeImage.from_file_map(file_map)
+    >>> np.all(img2.get_data() == data)
+    True
+    >>> # write, read it again
+    >>> img2.to_file_map()
+    >>> img3 = nib.AnalyzeImage.from_file_map(file_map)
+    >>> np.all(img3.get_data() == data)
+    True
 
 '''
 
-try:
-    basestring
-except NameError:  # python 3
-    basestring = str
-
-import warnings
-
 import numpy as np
 
-from .filename_parser import types_filenames, TypesFilenamesError
-from .fileholders import FileHolder
+from .filebasedimages import FileBasedHeader, FileBasedImage
+from .filebasedimages import ImageFileError  # flake8: noqa; for back-compat
+from .viewers import OrthoSlicer3D
 from .volumeutils import shape_zoom_affine
+from .deprecated import deprecate_with_version
 
 
 class HeaderDataError(Exception):
     ''' Class to indicate error in getting or setting header data '''
-    pass
 
 
 class HeaderTypeError(Exception):
     ''' Class to indicate error in parameters into header functions '''
-    pass
 
 
-class Header(object):
+class SpatialHeader(FileBasedHeader):
     ''' Template class to implement header protocol '''
     default_x_flip = True
     data_layout = 'F'
@@ -229,7 +223,7 @@ class Header(object):
         self._shape = tuple([int(s) for s in shape])
         # set any unset zooms to 1.0
         nzs = min(len(self._zooms), ndim)
-        self._zooms = self._zooms[:nzs] + (1.0,) * (ndim-nzs)
+        self._zooms = self._zooms[:nzs] + (1.0,) * (ndim - nzs)
 
     def get_zooms(self):
         return self._zooms
@@ -310,27 +304,32 @@ def supported_np_types(obj):
     return set(supported)
 
 
+class Header(SpatialHeader):
+    '''Alias for SpatialHeader; kept for backwards compatibility.'''
+
+    @deprecate_with_version('Header class is deprecated.\n'
+                            'Please use SpatialHeader instead.'
+                            'instead.',
+                            '2.1', '4.0')
+    def __init__(self, *args, **kwargs):
+        super(Header, self).__init__(*args, **kwargs)
+
+
 class ImageDataError(Exception):
     pass
 
 
-class ImageFileError(Exception):
-    pass
+class SpatialImage(FileBasedImage):
+    ''' Template class for volumetric (3D/4D) images '''
+    header_class = SpatialHeader
 
-
-class SpatialImage(object):
-    header_class = Header
-    files_types = (('image', None),)
-    _compressed_exts = ()
-
-    ''' Template class for images '''
     def __init__(self, dataobj, affine, header=None,
                  extra=None, file_map=None):
         ''' Initialize image
 
         The image is a combination of (array, affine matrix, header), with
-        optional metadata in `extra`, and filename / file-like objects contained
-        in the `file_map` mapping.
+        optional metadata in `extra`, and filename / file-like objects
+        contained in the `file_map` mapping.
 
         Parameters
         ----------
@@ -351,6 +350,8 @@ class SpatialImage(object):
         file_map : mapping, optional
            mapping giving file information for this image format
         '''
+        super(SpatialImage, self).__init__(header=header, extra=extra,
+                                           file_map=file_map)
         self._dataobj = dataobj
         if not affine is None:
             # Check that affine is array-like 4,4.  Maybe this is too strict at
@@ -359,31 +360,24 @@ class SpatialImage(object):
             # Copy affine to isolate from environment.  Specify float type to
             # avoid surprising integer rounding when setting values into affine
             affine = np.array(affine, dtype=np.float64, copy=True)
-            if not affine.shape == (4,4):
+            if not affine.shape == (4, 4):
                 raise ValueError('Affine should be shape 4,4')
         self._affine = affine
-        if extra is None:
-            extra = {}
-        self.extra = extra
-        self._header = self.header_class.from_header(header)
+
         # if header not specified, get data type from input array
         if header is None:
             if hasattr(dataobj, 'dtype'):
                 self._header.set_data_dtype(dataobj.dtype)
         # make header correspond with image and affine
         self.update_header()
-        if file_map is None:
-            file_map = self.__class__.make_file_map()
-        self.file_map = file_map
         self._load_cache = None
         self._data_cache = None
 
     @property
+    @deprecate_with_version('_data attribute not part of public API. '
+                            'please use "dataobj" property instead.',
+                            '2.0', '4.0')
     def _data(self):
-        warnings.warn('Please use ``dataobj`` instead of ``_data``; '
-                      'We will remove this wrapper for ``_data`` soon',
-                      FutureWarning,
-                      stacklevel=2)
         return self._dataobj
 
     @property
@@ -394,10 +388,6 @@ class SpatialImage(object):
     def affine(self):
         return self._affine
 
-    @property
-    def header(self):
-        return self._header
-
     def update_header(self):
         ''' Harmonize header with image data and affine
 
@@ -419,8 +409,8 @@ class SpatialImage(object):
         # maybe it happened
         if hdr.get_data_shape() != shape:
             hdr.set_data_shape(shape)
-        # If the affine is not None, and it is different from the main affine in
-        # the header, update the heaader
+        # If the affine is not None, and it is different from the main affine
+        # in the header, update the heaader
         if self._affine is None:
             return
         if np.allclose(self._affine, hdr.get_best_affine()):
@@ -440,13 +430,12 @@ class SpatialImage(object):
     def __str__(self):
         shape = self.shape
         affine = self.affine
-        return '\n'.join((
-                str(self.__class__),
-                'data shape %s' % (shape,),
-                'affine: ',
-                '%s' % affine,
-                'metadata:',
-                '%s' % self._header))
+        return '\n'.join((str(self.__class__),
+                          'data shape %s' % (shape,),
+                          'affine: ',
+                          '%s' % affine,
+                          'metadata:',
+                          '%s' % self._header))
 
     def get_data(self, caching='fill'):
         """ Return image data from image with any necessary scalng applied
@@ -534,11 +523,12 @@ class SpatialImage(object):
         True
 
         The array is not yet cached by a call to "get_data", so:
+
         >>> img.in_memory
         False
 
-        After we call ``get_data`` using the default `caching='fill', the cache
-        contains a reference to the returned array ``data``:
+        After we call ``get_data`` using the default `caching` == 'fill', the
+        cache contains a reference to the returned array ``data``:
 
         >>> data = img.get_data()
         >>> img.in_memory
@@ -622,14 +612,13 @@ class SpatialImage(object):
     def shape(self):
         return self._dataobj.shape
 
+    @deprecate_with_version('get_shape method is deprecated.\n'
+                            'Please use the ``img.shape`` property '
+                            'instead.',
+                            '1.2', '3.0')
     def get_shape(self):
         """ Return shape for image
-
-        This function deprecated; please use the ``shape`` property instead
         """
-        warnings.warn('Please use the shape property instead of get_shape',
-                      DeprecationWarning,
-                      stacklevel=2)
         return self.shape
 
     def get_data_dtype(self):
@@ -638,214 +627,15 @@ class SpatialImage(object):
     def set_data_dtype(self, dtype):
         self._header.set_data_dtype(dtype)
 
+    @deprecate_with_version('get_affine method is deprecated.\n'
+                            'Please use the ``img.affine`` property '
+                            'instead.',
+                            '2.1', '4.0')
     def get_affine(self):
         """ Get affine from image
-
-        Please use the `affine` property instead of `get_affine`; we will
-        deprecate this method in future versions of nibabel.
         """
         return self.affine
 
-    def get_header(self):
-        """ Get header from image
-
-        Please use the `header` property instead of `get_header`; we will
-        deprecate this method in future versions of nibabel.
-        """
-        return self.header
-
-    def get_filename(self):
-        ''' Fetch the image filename
-
-        Parameters
-        ----------
-        None
-
-        Returns
-        -------
-        fname : None or str
-           Returns None if there is no filename, or a filename string.
-           If an image may have several filenames assoctiated with it
-           (e.g Analyze ``.img, .hdr`` pair) then we return the more
-           characteristic filename (the ``.img`` filename in the case of
-           Analyze')
-        '''
-        # which filename is returned depends on the ordering of the
-        # 'files_types' class attribute - we return the name
-        # corresponding to the first in that tuple
-        characteristic_type = self.files_types[0][0]
-        return self.file_map[characteristic_type].filename
-
-    def set_filename(self, filename):
-        ''' Sets the files in the object from a given filename
-
-        The different image formats may check whether the filename has
-        an extension characteristic of the format, and raise an error if
-        not.
-
-        Parameters
-        ----------
-        filename : str
-           If the image format only has one file associated with it,
-           this will be the only filename set into the image
-           ``.file_map`` attribute. Otherwise, the image instance will
-           try and guess the other filenames from this given filename.
-        '''
-        self.file_map = self.__class__.filespec_to_file_map(filename)
-
-    @classmethod
-    def from_filename(klass, filename):
-        file_map = klass.filespec_to_file_map(filename)
-        return klass.from_file_map(file_map)
-
-    @classmethod
-    def from_filespec(klass, filespec):
-        warnings.warn('``from_filespec`` class method is deprecated\n'
-                      'Please use the ``from_filename`` class method '
-                      'instead',
-                      DeprecationWarning, stacklevel=2)
-        klass.from_filename(filespec)
-
-    @classmethod
-    def from_file_map(klass, file_map):
-        raise NotImplementedError
-
-    @classmethod
-    def from_files(klass, file_map):
-        warnings.warn('``from_files`` class method is deprecated\n'
-                      'Please use the ``from_file_map`` class method '
-                      'instead',
-                      DeprecationWarning, stacklevel=2)
-        return klass.from_file_map(file_map)
-
-    @classmethod
-    def filespec_to_file_map(klass, filespec):
-        """ Make `file_map` for this class from filename `filespec`
-
-        Class method
-
-        Parameters
-        ----------
-        filespec : str
-            Filename that might be for this image file type.
-
-        Returns
-        -------
-        file_map : dict
-            `file_map` dict with (key, value) pairs of (``file_type``,
-            FileHolder instance), where ``file_type`` is a string giving the
-            type of the contained file.
-
-        Raises
-        ------
-        ImageFileError
-            if `filespec` is not recognizable as being a filename for this
-            image type.
-        """
-        try:
-            filenames = types_filenames(filespec,
-                                        klass.files_types,
-                                        trailing_suffixes=klass._compressed_exts)
-        except TypesFilenamesError:
-            raise ImageFileError(
-                'Filespec "{0}" does not look right for class {1}'.format(
-                    filespec, klass))
-        file_map = {}
-        for key, fname in filenames.items():
-            file_map[key] = FileHolder(filename=fname)
-        return file_map
-
-    @classmethod
-    def filespec_to_files(klass, filespec):
-        warnings.warn('``filespec_to_files`` class method is deprecated\n'
-                      'Please use the ``filespec_to_file_map`` class method '
-                      'instead',
-                      DeprecationWarning, stacklevel=2)
-        return klass.filespec_to_file_map(filespec)
-
-    def to_filename(self, filename):
-        ''' Write image to files implied by filename string
-
-        Parameters
-        ----------
-        filename : str
-           filename to which to save image.  We will parse `filename`
-           with ``filespec_to_file_map`` to work out names for image,
-           header etc.
-
-        Returns
-        -------
-        None
-        '''
-        self.file_map = self.filespec_to_file_map(filename)
-        self.to_file_map()
-
-    def to_filespec(self, filename):
-        warnings.warn('``to_filespec`` is deprecated, please '
-                      'use ``to_filename`` instead',
-                      DeprecationWarning, stacklevel=2)
-        self.to_filename(filename)
-
-    def to_file_map(self, file_map=None):
-        raise NotImplementedError
-
-    def to_files(self, file_map=None):
-        warnings.warn('``to_files`` method is deprecated\n'
-                      'Please use the ``to_file_map`` method '
-                      'instead',
-                      DeprecationWarning, stacklevel=2)
-        self.to_file_map(file_map)
-
-    @classmethod
-    def make_file_map(klass, mapping=None):
-        ''' Class method to make files holder for this image type
-
-        Parameters
-        ----------
-        mapping : None or mapping, optional
-           mapping with keys corresponding to image file types (such as
-           'image', 'header' etc, depending on image class) and values
-           that are filenames or file-like.  Default is None
-
-        Returns
-        -------
-        file_map : dict
-           dict with string keys given by first entry in tuples in
-           sequence klass.files_types, and values of type FileHolder,
-           where FileHolder objects have default values, other than
-           those given by `mapping`
-        '''
-        if mapping is None:
-            mapping = {}
-        file_map = {}
-        for key, ext in klass.files_types:
-            file_map[key] = FileHolder()
-            mapval = mapping.get(key, None)
-            if isinstance(mapval, basestring):
-                file_map[key].filename = mapval
-            elif hasattr(mapval, 'tell'):
-                file_map[key].fileobj = mapval
-        return file_map
-
-    load = from_filename
-
-    @classmethod
-    def instance_to_filename(klass, img, filename):
-        ''' Save `img` in our own format, to name implied by `filename`
-
-        This is a class method
-
-        Parameters
-        ----------
-        img : ``spatialimage`` instance
-           In fact, an object with the API of ``spatialimage`` - specifically
-           ``dataobj``, ``affine``, ``header`` and ``extra``.
-        filename : str
-           Filename, implying name to which to save image.
-        '''
-        img = klass.from_image(img)
-        img.to_filename(filename)
-
     @classmethod
     def from_image(klass, img):
         ''' Class method to create new instance of own class from `img`
@@ -872,3 +662,20 @@ class SpatialImage(object):
         raise TypeError("Cannot slice image objects; consider slicing image "
                         "array data with `img.dataobj[slice]` or "
                         "`img.get_data()[slice]`")
+
+    def orthoview(self):
+        """Plot the image using OrthoSlicer3D
+
+        Returns
+        -------
+        viewer : instance of OrthoSlicer3D
+            The viewer.
+
+        Notes
+        -----
+        This requires matplotlib. If a non-interactive backend is used,
+        consider using viewer.show() (equivalently plt.show()) to show
+        the figure.
+        """
+        return OrthoSlicer3D(self.dataobj, self.affine,
+                             title=self.get_filename())
