@@ -9,21 +9,23 @@
 """ Testing spatialimages
 
 """
-from ..externals.six import BytesIO
+
+import warnings
+
 import numpy as np
 
-from ..spatialimages import (Header, SpatialImage, HeaderDataError,
-                             ImageDataError)
+from ..externals.six import BytesIO
+from ..spatialimages import (SpatialHeader, SpatialImage, HeaderDataError,
+                             Header, ImageDataError)
 
 from unittest import TestCase
-
 from nose.tools import (assert_true, assert_false, assert_equal,
                         assert_not_equal, assert_raises)
-
 from numpy.testing import assert_array_equal, assert_array_almost_equal
 
 from .test_helpers import bytesio_round_trip
-from ..testing import suppress_warnings
+from ..testing import (clear_and_catch_warnings, suppress_warnings,
+                       VIRAL_MEMMAP)
 from ..tmpdirs import InTemporaryDirectory
 from .. import load as top_load
 
@@ -38,17 +40,17 @@ def test_header_init():
     assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
     assert_equal(hdr.get_data_shape(), (0,))
     assert_equal(hdr.get_zooms(), (1.0,))
-    hdr = Header(np.float64, shape=(1,2,3))
+    hdr = Header(np.float64, shape=(1, 2, 3))
     assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1,2,3))
+    assert_equal(hdr.get_data_shape(), (1, 2, 3))
     assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
-    hdr = Header(np.float64, shape=(1,2,3), zooms=None)
+    hdr = Header(np.float64, shape=(1, 2, 3), zooms=None)
     assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1,2,3))
+    assert_equal(hdr.get_data_shape(), (1, 2, 3))
     assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
-    hdr = Header(np.float64, shape=(1,2,3), zooms=(3.0, 2.0, 1.0))
+    hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     assert_equal(hdr.get_data_dtype(), np.dtype(np.float64))
-    assert_equal(hdr.get_data_shape(), (1,2,3))
+    assert_equal(hdr.get_data_shape(), (1, 2, 3))
     assert_equal(hdr.get_zooms(), (3.0, 2.0, 1.0))
 
 
@@ -59,19 +61,23 @@ def test_from_header():
     assert_equal(Header(), empty)
     empty = Header.from_header(None)
     assert_equal(Header(), empty)
-    hdr = Header(np.float64, shape=(1,2,3), zooms=(3.0, 2.0, 1.0))
+    hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     copy = Header.from_header(hdr)
     assert_equal(hdr, copy)
     assert_false(hdr is copy)
+
     class C(object):
+
         def get_data_dtype(self): return np.dtype('u2')
-        def get_data_shape(self): return (5,4,3)
+
+        def get_data_shape(self): return (5, 4, 3)
+
         def get_zooms(self): return (10.0, 9.0, 8.0)
     converted = Header.from_header(C())
     assert_true(isinstance(converted, Header))
     assert_equal(converted.get_data_dtype(), np.dtype('u2'))
-    assert_equal(converted.get_data_shape(), (5,4,3))
-    assert_equal(converted.get_zooms(), (10.0,9.0,8.0))
+    assert_equal(converted.get_data_shape(), (5, 4, 3))
+    assert_equal(converted.get_zooms(), (10.0, 9.0, 8.0))
 
 
 def test_eq():
@@ -80,25 +86,25 @@ def test_eq():
     assert_equal(hdr, other)
     other = Header('u2')
     assert_not_equal(hdr, other)
-    other = Header(shape=(1,2,3))
+    other = Header(shape=(1, 2, 3))
     assert_not_equal(hdr, other)
-    hdr = Header(shape=(1,2))
-    other = Header(shape=(1,2))
+    hdr = Header(shape=(1, 2))
+    other = Header(shape=(1, 2))
     assert_equal(hdr, other)
-    other = Header(shape=(1,2), zooms=(2.0,3.0))
+    other = Header(shape=(1, 2), zooms=(2.0, 3.0))
     assert_not_equal(hdr, other)
 
 
 def test_copy():
     # test that copy makes independent copy
-    hdr = Header(np.float64, shape=(1,2,3), zooms=(3.0, 2.0, 1.0))
+    hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     hdr_copy = hdr.copy()
-    hdr.set_data_shape((4,5,6))
-    assert_equal(hdr.get_data_shape(), (4,5,6))
-    assert_equal(hdr_copy.get_data_shape(), (1,2,3))
-    hdr.set_zooms((4,5,6))
-    assert_equal(hdr.get_zooms(), (4,5,6))
-    assert_equal(hdr_copy.get_zooms(), (3,2,1))
+    hdr.set_data_shape((4, 5, 6))
+    assert_equal(hdr.get_data_shape(), (4, 5, 6))
+    assert_equal(hdr_copy.get_data_shape(), (1, 2, 3))
+    hdr.set_zooms((4, 5, 6))
+    assert_equal(hdr.get_zooms(), (4, 5, 6))
+    assert_equal(hdr_copy.get_zooms(), (3, 2, 1))
     hdr.set_data_dtype(np.uint8)
     assert_equal(hdr.get_data_dtype(), np.dtype(np.uint8))
     assert_equal(hdr_copy.get_data_dtype(), np.dtype(np.float64))
@@ -107,16 +113,16 @@ def test_copy():
 def test_shape_zooms():
     hdr = Header()
     hdr.set_data_shape((1, 2, 3))
-    assert_equal(hdr.get_data_shape(), (1,2,3))
-    assert_equal(hdr.get_zooms(), (1.0,1.0,1.0))
+    assert_equal(hdr.get_data_shape(), (1, 2, 3))
+    assert_equal(hdr.get_zooms(), (1.0, 1.0, 1.0))
     hdr.set_zooms((4, 3, 2))
-    assert_equal(hdr.get_zooms(), (4.0,3.0,2.0))    
+    assert_equal(hdr.get_zooms(), (4.0, 3.0, 2.0))
     hdr.set_data_shape((1, 2))
-    assert_equal(hdr.get_data_shape(), (1,2))
-    assert_equal(hdr.get_zooms(), (4.0,3.0))
+    assert_equal(hdr.get_data_shape(), (1, 2))
+    assert_equal(hdr.get_zooms(), (4.0, 3.0))
     hdr.set_data_shape((1, 2, 3))
-    assert_equal(hdr.get_data_shape(), (1,2,3))
-    assert_equal(hdr.get_zooms(), (4.0,3.0,1.0))
+    assert_equal(hdr.get_data_shape(), (1, 2, 3))
+    assert_equal(hdr.get_zooms(), (4.0, 3.0, 1.0))
     # null shape is (0,)
     hdr.set_data_shape(())
     assert_equal(hdr.get_data_shape(), (0,))
@@ -124,12 +130,12 @@ def test_shape_zooms():
     # zooms of wrong lengths raise error
     assert_raises(HeaderDataError, hdr.set_zooms, (4.0, 3.0))
     assert_raises(HeaderDataError,
-                        hdr.set_zooms,
-                        (4.0, 3.0, 2.0, 1.0))
+                  hdr.set_zooms,
+                  (4.0, 3.0, 2.0, 1.0))
     # as do negative zooms
     assert_raises(HeaderDataError,
-                        hdr.set_zooms,
-                        (4.0, 3.0, -2.0))
+                  hdr.set_zooms,
+                  (4.0, 3.0, -2.0))
 
 
 def test_data_dtype():
@@ -142,29 +148,29 @@ def test_data_dtype():
 
 
 def test_affine():
-    hdr = Header(np.float64, shape=(1,2,3), zooms=(3.0, 2.0, 1.0))
+    hdr = Header(np.float64, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
     assert_array_almost_equal(hdr.get_best_affine(),
-                                    [[-3.0,0,0,0],
-                                     [0,2,0,-1],
-                                     [0,0,1,-1],
-                                     [0,0,0,1]])
+                              [[-3.0, 0, 0, 0],
+                               [0, 2, 0, -1],
+                               [0, 0, 1, -1],
+                               [0, 0, 0, 1]])
     hdr.default_x_flip = False
     assert_array_almost_equal(hdr.get_best_affine(),
-                                    [[3.0,0,0,0],
-                                     [0,2,0,-1],
-                                     [0,0,1,-1],
-                                     [0,0,0,1]])
+                              [[3.0, 0, 0, 0],
+                               [0, 2, 0, -1],
+                               [0, 0, 1, -1],
+                               [0, 0, 0, 1]])
     assert_array_equal(hdr.get_base_affine(),
                        hdr.get_best_affine())
 
 
 def test_read_data():
-    class CHeader(Header):
-        data_layout='C'
-    for klass, order in ((Header, 'F'), (CHeader, 'C')):
-        hdr = klass(np.int32, shape=(1,2,3), zooms=(3.0, 2.0, 1.0))
+    class CHeader(SpatialHeader):
+        data_layout = 'C'
+    for klass, order in ((SpatialHeader, 'F'), (CHeader, 'C')):
+        hdr = klass(np.int32, shape=(1, 2, 3), zooms=(3.0, 2.0, 1.0))
         fobj = BytesIO()
-        data = np.arange(6).reshape((1,2,3))
+        data = np.arange(6).reshape((1, 2, 3))
         hdr.data_to_fileobj(data, fobj)
         assert_equal(fobj.getvalue(),
                      data.astype(np.int32).tostring(order=order))
@@ -187,6 +193,7 @@ def test_read_data():
 class DataLike(object):
     # Minimal class implementing 'data' API
     shape = (3,)
+
     def __array__(self):
         return np.arange(3)
 
@@ -203,7 +210,7 @@ class TestSpatialImage(TestCase):
         aff = np.eye(4)
         img = img_klass(arr, aff)
         assert_array_equal(img.affine, aff)
-        aff[0,0] = 99
+        aff[0, 0] = 99
         assert_false(np.all(img.affine == aff))
         # header, created by image creation
         ihdr = img.header
@@ -255,7 +262,7 @@ class TestSpatialImage(TestCase):
         # is None, and that unsupported dtypes raise an error
         img_klass = self.image_class
         hdr_klass = self.image_class.header_class
-        data = np.arange(24, dtype=np.int32).reshape((2,3,4))
+        data = np.arange(24, dtype=np.int32).reshape((2, 3, 4))
         affine = np.eye(4)
         img = img_klass(data, affine)
         self.check_dtypes(data.dtype, img.get_data_dtype())
@@ -272,8 +279,8 @@ class TestSpatialImage(TestCase):
         arr = np.arange(4, dtype=np.int16)
         img = img_klass(arr, np.eye(4))
         assert_equal(img.shape, (4,))
-        img = img_klass(np.zeros((2,3,4), dtype=np.float32), np.eye(4))
-        assert_equal(img.shape, (2,3,4))
+        img = img_klass(np.zeros((2, 3, 4), dtype=np.float32), np.eye(4))
+        assert_equal(img.shape, (2, 3, 4))
 
     def test_str(self):
         # Check something comes back from string representation
@@ -284,7 +291,7 @@ class TestSpatialImage(TestCase):
         img = img_klass(arr, np.eye(4))
         assert_true(len(str(img)) > 0)
         assert_equal(img.shape, (5,))
-        img = img_klass(np.zeros((2,3,4), dtype=np.int16), np.eye(4))
+        img = img_klass(np.zeros((2, 3, 4), dtype=np.int16), np.eye(4))
         assert_true(len(str(img)) > 0)
 
     def test_get_shape(self):
@@ -296,8 +303,8 @@ class TestSpatialImage(TestCase):
         img = img_klass(np.arange(1, dtype=np.int16), np.eye(4))
         with suppress_warnings():
             assert_equal(img.get_shape(), (1,))
-            img = img_klass(np.zeros((2,3,4), np.int16), np.eye(4))
-            assert_equal(img.get_shape(), (2,3,4))
+            img = img_klass(np.zeros((2, 3, 4), np.int16), np.eye(4))
+            assert_equal(img.get_shape(), (2, 3, 4))
 
     def test_get_data(self):
         # Test array image and proxy image interface
@@ -328,14 +335,59 @@ class TestSpatialImage(TestCase):
         assert_false(rt_img.get_data() is out_data)
         assert_array_equal(rt_img.get_data(), in_data)
 
+    def test_api_deprecations(self):
+
+        class FakeImage(self.image_class):
+
+            files_types = (('image', '.foo'),)
+
+            @classmethod
+            def to_file_map(self, file_map=None):
+                pass
+
+            @classmethod
+            def from_file_map(self, file_map=None):
+                pass
+
+        arr = np.arange(24, dtype=np.int16).reshape((2, 3, 4))
+        aff = np.eye(4)
+        img = FakeImage(arr, aff)
+        bio = BytesIO()
+        file_map = FakeImage.make_file_map({'image': bio})
+
+        with clear_and_catch_warnings() as w:
+            warnings.simplefilter('always', DeprecationWarning)
+            img.to_files(file_map)
+            assert_equal(len(w), 1)
+            img.to_filespec('an_image')
+            assert_equal(len(w), 2)
+            img = FakeImage.from_files(file_map)
+            assert_equal(len(w), 3)
+            file_map = FakeImage.filespec_to_files('an_image')
+            assert_equal(list(file_map), ['image'])
+            assert_equal(file_map['image'].filename, 'an_image.foo')
+            assert_equal(len(w), 4)
+
 
 class MmapImageMixin(object):
     """ Mixin for testing images that may return memory maps """
     #: whether to test mode of returned memory map
     check_mmap_mode = True
 
-    def write_image(self):
-        """ Return an image and an image filname to test against
+    def get_disk_image(self):
+        """ Return image, image filename, and flag for required scaling
+
+        Subclasses can do anything to return an image, including loading a
+        pre-existing image from disk.
+
+        Returns
+        -------
+        img : class:`SpatialImage` instance
+        fname : str
+            Image filename.
+        has_scaling : bool
+            True if the image array has scaling to apply to the raw image array
+            data, False otherwise.
         """
         img_klass = self.image_class
         shape = (3, 4, 2)
@@ -343,37 +395,45 @@ class MmapImageMixin(object):
         img = img_klass(data, None)
         fname = 'test' + img_klass.files_types[0][1]
         img.to_filename(fname)
-        return img, fname
+        return img, fname, False
 
     def test_load_mmap(self):
         # Test memory mapping when loading images
         img_klass = self.image_class
         with InTemporaryDirectory():
-            # This should have no scaling, can be mmapped
-            img, fname = self.write_image()
+            img, fname, has_scaling = self.get_disk_image()
             file_map = img.file_map.copy()
             for func, param1 in ((img_klass.from_filename, fname),
                                  (img_klass.load, fname),
                                  (top_load, fname),
                                  (img_klass.from_file_map, file_map)):
                 for mmap, expected_mode in (
-                    # mmap value, expected memmap mode
-                    # mmap=None -> no mmap value
-                    # expected mode=None -> no memmap returned
-                    (None, 'c'),
-                    (True, 'c'),
-                    ('c', 'c'),
-                    ('r', 'r'),
-                    (False, None)):
+                        # mmap value, expected memmap mode
+                        # mmap=None -> no mmap value
+                        # expected mode=None -> no memmap returned
+                        (None, 'c'),
+                        (True, 'c'),
+                        ('c', 'c'),
+                        ('r', 'r'),
+                        (False, None)):
+                    # If the image has scaling, then numpy 1.12 will not return
+                    # a memmap, regardless of the input flags.  Previous
+                    # numpies returned a memmap object, even though the array
+                    # has no mmap memory backing.  See:
+                    # https://github.com/numpy/numpy/pull/7406
+                    if has_scaling and not VIRAL_MEMMAP:
+                        expected_mode = None
                     kwargs = {}
                     if mmap is not None:
                         kwargs['mmap'] = mmap
                     back_img = func(param1, **kwargs)
                     back_data = back_img.get_data()
                     if expected_mode is None:
-                        assert_false(isinstance(back_data, np.memmap))
+                        assert_false(isinstance(back_data, np.memmap),
+                                     'Should not be a %s' % img_klass.__name__)
                     else:
-                        assert_true(isinstance(back_data, np.memmap))
+                        assert_true(isinstance(back_data, np.memmap),
+                                    'Not a %s' % img_klass.__name__)
                         if self.check_mmap_mode:
                             assert_equal(back_data.mode, expected_mode)
                     del back_img, back_data
@@ -382,3 +442,15 @@ class MmapImageMixin(object):
                 # Check invalid values raise error
                 assert_raises(ValueError, func, param1, mmap='rw')
                 assert_raises(ValueError, func, param1, mmap='r+')
+
+
+def test_header_deprecated():
+    with clear_and_catch_warnings() as w:
+        warnings.simplefilter('always', DeprecationWarning)
+
+        class MyHeader(Header):
+            pass
+        assert_equal(len(w), 0)
+
+        MyHeader()
+        assert_equal(len(w), 1)
